AmberResidueLibrary
==========================

.. currentmodule:: biskit

.. autoclass:: AmberResidueLibrary
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~AmberResidueLibrary.__init__
      ~AmberResidueLibrary.addTopology
      ~AmberResidueLibrary.atomkey
      ~AmberResidueLibrary.byAtoms
      ~AmberResidueLibrary.byName
      ~AmberResidueLibrary.keys
      ~AmberResidueLibrary.topokeys
      ~AmberResidueLibrary.values
   
   

   
   
   .. rubric:: Attributes Overview

   .. autosummary::
   
      ~AmberResidueLibrary.F_RESTYPES
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>AmberResidueLibrary Method & Attribute Details</h2>

   
   